Utilities
=========

RDF Namespaces
--------------

.. automodule:: eulfedora.rdfns
   :members:


Testing utilities
------------------
.. currentmodule:: eulfedora.testutil

.. automodule:: eulfedora.testutil
   :members:


Synchronization
---------------
.. automodule:: eulfedora.syncutil

.. automethod:: eulfedora.syncutil.sync_object

.. autoclass:: eulfedora.syncutil.ArchiveExport
    :members:

.. automethod:: eulfedora.syncutil.estimate_object_size


